#!/bin/sh

# The source here is entirely from a samba-2.2.* distribution
# EXCEPT for the following:
#	samba-2.2.sh		this file -- drives the build
#	samba-2.2-patches	the modifications to be applied

set -x
UWDIR=packaging/Caldera/UnixWare

# First apply the patches
[ -f samba-2.2-been-patched ] || {
	patch -p1 -i samba-2.2-patches || {
		echo '@#%$!: ERROR: something failed patching samba-2.2' 1>&2
		exit 2
	}
	date >samba-2.2-been-patched
}

set -e

# First create pkg/copyright from the Solaris and OpenServer ones
cat packaging/Solaris/copyright packaging/Caldera/OpenServer/copyrights >$UWDIR/pkg/copyright
ed $UWDIR/pkg/prototype <<!
4a
i copyright=copyright
.
w
q
!

# Create the $UWDIR multibyte files from the regular ones
mkdir $UWDIR/pkgmb || echo nevermind
cp $UWDIR/pkg/* $UWDIR/pkgmb
cp $UWDIR/smb.conf $UWDIR/smbmb.conf
cp $UWDIR/smb.init $UWDIR/smbmb.init

ed $UWDIR/smbmb.conf <<!
g;\([/9]\)samba;s;;\1sambamb;
w
q
!
ed $UWDIR/smbmb.init <<!
g;\([/9]\)samba;s;;\1sambamb;
w
q
!
ed $UWDIR/pkgmb/pkginfo <<!
g/[Ss]amba/s/mba/mbamb/
w
q
!
ed $UWDIR/pkgmb/postinstall <<!
g;/samba;s;;/sambamb;
w
q
!
ed $UWDIR/pkgmb/postremove <<!
g;/samba;s;;/sambamb;
w
q
!
ed $UWDIR/pkgmb/prototype <<!
g;\([/ ]\)samba\([/ ]\);s;;\1sambamb\2;g
g;usr/man;d
\$a
d sambamb usr/lib/scohelp 0755 root sys
d sambamb usr/lib/scohelp/en_US.ISO8859-1 0755 root sys
d sambamb usr/lib/scohelp/en_US.ISO8859-1/man 0755 root sys
s sambamb usr/lib/scohelp/en_US.ISO8859-1/man/html.1sambamb=/usr/lib/sambamb/swat/using_samba
.
w
q
!

# Configure, compile and install the regular version it into $UWDIR/dist
(cd $UWDIR; ./Configure)
(cd $UWDIR; ./Compile)
(cd $UWDIR; ./Install)

# Clean up and rebuild and install the multibyte version into $UWDIR/dist-mb
(cd source; ${MAKE-make} clean)
(cd $UWDIR; ./Configure -mb)
(cd $UWDIR; ./Compile -mb)
(cd $UWDIR; ./Install -mb)

# Create symbolic links in .../$WORK/pkg that points to $UWDIR/dist
# and $UWDIR/distmb so that packaging occurs when the build wants
# it to happen.
set +e
ln -s `pwd`/$UWDIR/dist $ROOT/usr/src/$WORK/pkg/samba
ln -s `pwd`/$UWDIR/distmb $ROOT/usr/src/$WORK/pkg/sambamb
